# Кодекс поведения участников Contributor Covenant

## Наше обязательство

Мы, как участники, контрибьюторы и лидеры, обязуемся сделать участие в нашем
сообществе свободным от преследований для всех, независимо от возраста, размера тела,
видимых или невидимых ограничений возможностей, этнической принадлежности, половых характеристик, гендерной
идентичности и самовыражения, уровня опыта, образования, социально-экономического статуса,
гражданства, внешнего вида, расы, религии или сексуальной идентичности
и ориентации.

Мы обязуемся действовать и взаимодействовать таким образом, чтобы способствовать созданию открытого, гостеприимного,
разнообразного, инклюзивного и здорового сообщества.

## Наши стандарты

Примеры поведения, способствующего созданию благоприятной среды для нашего
сообщества, включают:

* Проявление эмпатии и доброты по отношению к другим людям
* Уважение к различным мнениям, точкам зрения и опыту
* Предоставление и достойное принятие конструктивной обратной связи
* Принятие ответственности и извинение перед теми, кто пострадал от наших ошибок,
  а также извлечение уроков из этого опыта
* Фокусирование на том, что лучше не только для нас как индивидуумов, но и для
  всего сообщества в целом

Примеры неприемлемого поведения включают:

* Использование сексуализированного языка или образов, а также сексуальное внимание или
  домогательства любого рода
* Троллинг, оскорбительные или уничижительные комментарии, а также личные или политические нападки
* Публичное или частное преследование
* Публикация личной информации других лиц, такой как физический или электронный
  адрес, без их явного разрешения
* Другое поведение, которое может быть разумно расценено как неуместное в
  профессиональной обстановке

## Обязанности по обеспечению соблюдения

Лидеры сообщества несут ответственность за разъяснение и обеспечение соблюдения наших стандартов
приемлемого поведения и предпримут соответствующие и справедливые корректирующие действия
в ответ на любое поведение, которое они сочтут неприемлемым, угрожающим, оскорбительным
или вредным.

Лидеры сообщества имеют право и обязанность удалять, редактировать или отклонять
комментарии, коммиты, код, правки вики, вопросы и другие вклады, которые
не соответствуют настоящему Кодексу поведения, и будут сообщать причины решений
по модерации, когда это уместно.

## Область применения

Настоящий Кодекс поведения применяется во всех сообществах, а также в случаях,
когда человек официально представляет сообщество в публичных пространствах.
Примеры представления нашего сообщества включают использование официального адреса электронной почты,
публикации через официальный аккаунт в социальных сетях или выступление в качестве назначенного
представителя на онлайн- или оффлайн-мероприятиях.

## Применение

Случаи оскорбительного, преследующего или иного неприемлемого поведения могут быть
сообщены лидерам сообщества, ответственным за обеспечение соблюдения, по адресу
aw@funstory.ai.
Все жалобы будут рассмотрены и расследованы оперативно и справедливо.

Все лидеры сообщества обязаны уважать конфиденциальность и безопасность
сообщившего о любом инциденте.

## Руководство по применению

Лидеры сообщества будут следовать этим Руководствам по воздействию на сообщество при определении
последствий для любых действий, которые они сочтут нарушением данного Кодекса поведения:

### 1. Исправление

**Влияние на сообщество**: Использование неуместного языка или другое поведение, считающееся
непрофессиональным или нежелательным в сообществе.

**Последствие**: Частное письменное предупреждение от лидеров сообщества с разъяснением
сути нарушения и объяснением, почему поведение было неуместным. Может быть запрошено публичное извинение.

### 2. Предупреждение

**Влияние на сообщество**: Нарушение, совершенное в результате единичного инцидента или серии действий.

**Последствия**: Предупреждение с последствиями в случае продолжения подобного поведения. Запрет на взаимодействие с вовлеченными лицами, включая нежелательные контакты с теми, кто обеспечивает соблюдение Кодекса поведения, на определенный период времени. Это включает избегание взаимодействий как в пространствах сообщества, так и на внешних каналах, таких как социальные сети. Нарушение этих условий может привести к временной или постоянной блокировке.

### 3. Временная блокировка

**Влияние на сообщество**: Серьезное нарушение стандартов сообщества, включая
систематическое недопустимое поведение.

**Последствие**: Временная блокировка любого вида взаимодействия или публичного
общения с сообществом на определенный период времени. В течение этого периода
запрещено любое публичное или частное взаимодействие с вовлеченными лицами,
включая нежелательное взаимодействие с теми, кто обеспечивает соблюдение Кодекса поведения.
Нарушение этих условий может привести к постоянной блокировке.

### 4. Постоянная блокировка

**Влияние на сообщество**: Демонстрация систематического нарушения стандартов сообщества, включая устойчивое неадекватное поведение, преследование отдельного лица или агрессию в отношении или унижение групп лиц.

**Последствие**: Постоянная блокировка любого вида публичного взаимодействия в рамках сообщества.

## Атрибуция

Этот Кодекс поведения адаптирован из [Contributor Covenant][homepage],
версии 2.0, доступной по адресу
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html.

Руководство по влиянию на сообщество вдохновлено [лестницей применения кодекса поведения Mozilla](https://github.com/mozilla/diversity).

[homepage]: https://www.contributor-covenant.org

Ответы на часто задаваемые вопросы о данном кодексе поведения можно найти в разделе FAQ по адресу
https://www.contributor-covenant.org/faq. Переводы доступны на
https://www.contributor-covenant.org/translations.

<div align="right"> 
<h6><small>Часть содержимого этой страницы была переведена GPT и может содержать ошибки.</small></h6>